@@ -115,6 +115,22 @@ class CreateTrainingJobFailed(DARException):
     pass
 
 
+class JobNotFound(DARException):
+    """
+    Training job not found
+    """
+
+    pass
+
+
+class InvalidWorkerCount(DARException):
+    """
+    Invalid worker_count parameter is specified.
+
+    .. versionadded:: 0.12.0
+    """
+
+
 class ModelAlreadyExists(DARException):
     """
     Model already exists and must be deleted first.
